@@ -69,6 +69,7 @@ class CLI(cl1.CLI):
 				"    --stop-daemon <path>":"Stop a ssync daemon.",
 				"    --list-daemons":"List all daemons & their status.",
 				"Basic:":"*chapter*",
+				"    --sync":"Manually synchronize the aliases & add the keys to the agent.",
 				"    --kill <identifier>":"Kill all ssh processes that include the identifier.",
 				"    --config":"Edit the ssht00ls configuration file (nano).",
 				"    --reset-cache":"Reset the cache directory.",
@@ -98,8 +99,10 @@ class CLI(cl1.CLI):
 		self.arguments.check(json=syst3m.defaults.options.json, exceptions=["--log-level", "--version", "--create-alias", "--non-interative"])
 
 		# sync aliases.
-		if encryption.activated:
+		if encryption.activated or self.arguments.present("--sync"):
 			response = ssht00ls.aliases.sync()
+			if self.arguments.present("--sync"):
+				self.stop(response=response)
 			if not response["success"]: response.crash(json=syst3m.defaults.options.json)
 
 		#
@@ -116,7 +119,7 @@ class CLI(cl1.CLI):
 
 		# config.
 		elif self.arguments.present('--config'):
-			if JSON:
+			if syst3m.defaults.options.json:
 				print(CONFIG.dictionary)
 			else:
 				os.system(f"nano {CONFIG.file_path.path}")
@@ -156,7 +159,7 @@ class CLI(cl1.CLI):
 			response = ssht00ls.ssh.command(
 				alias=alias,
 				command=command,
-				serialize=JSON,)
+				serialize=syst3m.defaults.options.json,)
 			if not response.success:
 				self.stop(response=response)
 			else:
@@ -169,7 +172,7 @@ class CLI(cl1.CLI):
 		# list aliases.
 		elif self.arguments.present("--list-aliases"):
 			array = Array(array=ssht00ls.aliases.list())
-			if JSON:
+			if syst3m.defaults.options.json:
 				print(array.array)
 			else:
 				joiner = self.arguments.get("--joiner", required=False, default="\n")
@@ -197,7 +200,7 @@ class CLI(cl1.CLI):
 
 				# show info.
 				if self.arguments.present('--info'):
-					if JSON:
+					if syst3m.defaults.options.json:
 						info[alias] = {alias:alias_info}
 					else:
 						print(self.__str_representable__({alias:alias_info}, start_indent=0))
@@ -324,7 +327,7 @@ class CLI(cl1.CLI):
 				else: self.invalid(chapter="aliases", json=syst3m.defaults.options.json)
 
 			# json show info joined.
-			if JSON and self.arguments.present('--info'):
+			if syst3m.defaults.options.json and self.arguments.present('--info'):
 				print(info)
 
 		#
@@ -415,6 +418,7 @@ class CLI(cl1.CLI):
 
 		# mount.
 		elif self.arguments.present('--mount'):
+			self.stop(error="Coming soon.")
 			remote = self.arguments.get("--mount", index=1, chapter="mounts", mode="--mount", notes={})
 			path = self.arguments.get("--mount", index=2, chapter="mounts", mode="--mount", notes={})
 			if ":" not in remote:
@@ -438,6 +442,7 @@ class CLI(cl1.CLI):
 
 		# sync.
 		elif self.arguments.present('--sync'):
+			self.stop(error="Coming soon.")
 			remote = self.arguments.get("--sync", index=1, chapter="mounts", mode="--sync", notes={})
 			path = self.arguments.get("--sync", index=2, chapter="mounts", mode="--sync", notes={})
 			if ":" not in remote:
@@ -474,10 +479,10 @@ class CLI(cl1.CLI):
 			index = self.arguments.get("--index", chapter="mounts", mode="--index")
 			if ":" in index:
 				alias,remote = index.split(":")
-				path = syst3m.env.fill(path)
+				remote = syst3m.env.fill(remote)
 				response = ssht00ls.ssync.index(path=remote, alias=alias)
 			else:
-				path = syst3m.env.fill(path)
+				index = syst3m.env.fill(index)
 				response = ssht00ls.ssync.index(path=index)
 			self.stop(response=response, json=syst3m.defaults.options.json)
 
