@@ -31,8 +31,10 @@ class Agent(object):
 		
 		#
 	def add(self, 
-		# the keys path.
-		path=None, 
+		# the private key's path.
+		private_key=None, 
+		# the public key's path (optional).
+		public_key=None, 
 		# the keys passphrase.
 		passphrase=None, 
 		# enable if you are using a smart card.
@@ -47,13 +49,13 @@ class Agent(object):
 
 		# check specific.
 		if self.specific:
-			if path == None: path = self.private_key
+			if private_key == None: private_key = self.private_key
 			if smartcard == None: smartcard = self.smartcard
 
 		# initialize.
-		path = path.replace("//", "/")
+		private_key = private_key.replace("//", "/")
 		response = r3sponse.check_parameters(empty_value=None, parameters={
-			"path":path
+			"private_key":private_key
 		})
 		if not response["success"]: return response
 		if smartcard:
@@ -62,11 +64,12 @@ class Agent(object):
 			})
 			if not response["success"]: return response
 		else:
-			if not Files.exists(path):
-				return r3sponse.error(f"Key path [{path}] does not exist.")
-			public_key = path.replace("/private_key","/public_key")
+			if not Files.exists(private_key):
+				return r3sponse.error(f"Private key [{private_key}] does not exist.")
+			if public_key == None:
+				public_key = private_key.replace("/private_key","/public_key")
 			if not Files.exists(public_key):
-				return r3sponse.error(f"Key path [{public_key}] does not exist.")
+				return r3sponse.error(f"Public key [{public_key}] does not exist.")
 
 		# check agent connection.
 		output = utils.__execute__(["ssh-add", "-L"])
@@ -75,7 +78,7 @@ class Agent(object):
 				ssh.utils.ssh_agent()
 				return self.add(
 					# the keys path.
-					path=path,
+					private_key=private_key,
 					# the keys passphrase.
 					passphrase=passphrase,
 					# enable if you are using a smart card.
@@ -94,25 +97,25 @@ class Agent(object):
 		if not smartcard:
 			response = self.check(public_key=public_key, raw=False)
 			if response.success:
-				return r3sponse.success(f"Key [{path}] is already added to the ssh agent.")
+				return r3sponse.success(f"Key [{private_key}] is already added to the ssh agent.")
 
 		# with passphrase.
 		if smartcard or passphrase not in [False, None, "", "none", "None"]:
 			if smartcard:
-				path = smartcards.path
+				private_key = smartcards.path
 				if syst3m.defaults.vars.os in ["macos"]:
 					os.system(f"rm -fr {smartcards.path}")
 					os.system(f"cp {smartcards.original_path} {smartcards.path}")
 					os.system(f"chmod 644 {smartcards.path}")
 				#try:
-				#	output = subprocess.check_output([f"ssh-add", "-e", f"{path}"])
+				#	output = subprocess.check_output([f"ssh-add", "-e", f"{private_key}"])
 				#	print("remove card output:",output)
 				#except: a=1
-				spawn = pexpect.spawn(f'ssh-add -s {path}')
+				spawn = pexpect.spawn(f'ssh-add -s {private_key}')
 			else:
 
 				# start.
-				spawn = pexpect.spawn(f'ssh-add {path}')
+				spawn = pexpect.spawn(f'ssh-add {private_key}')
 
 			# send lines.
 			output = None
@@ -129,7 +132,7 @@ class Agent(object):
 				# handle pass.
 				else:
 					spawn.expect(
-						f'Enter passphrase for {path}:',
+						f'Enter passphrase for {private_key}:',
 						timeout=timeout,
 					)
 					spawn.sendline(passphrase)
@@ -152,7 +155,7 @@ class Agent(object):
 					ssh.utils.ssh_agent()
 					return self.add(
 						# the keys path.
-						path=path,
+						private_key=private_key,
 						# the keys passphrase.
 						passphrase=passphrase,
 						# enable if you are using a smart card.
@@ -167,29 +170,37 @@ class Agent(object):
 				else:
 					return r3sponse.error("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
 			elif "Identity added:" in output or "Card added:" in output: 
-				return r3sponse.success(f"Successfully added key [{path}] to the ssh agent.")
+				return r3sponse.success(f"Successfully added key [{private_key}] to the ssh agent.")
 			elif output != "": 
-				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
+				return r3sponse.error(f"Failed to add key [{private_key}] to the ssh agent, error: {output}")
 			else: 
-				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
+				# no output check if key added.
+				if not smartcard:
+					response = self.check(public_key=public_key, raw=False)
+					if response.success:
+						return r3sponse.success(f"Successfully added key [{private_key}] to the ssh agent.")
+					else:
+						return r3sponse.error(f"Failed to add key [{private_key}] to the ssh agent (#2).")
+				else:
+					return r3sponse.error(f"Failed to add key [{private_key}] to the ssh agent (#1).")
 
 			# handle eof.
 			"""try:
 				spawn.expect(pexpect.EOF, timeout=timeout)
 			except pexpect.ExceptionPexpect as epe:
-				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent #3.")"""
+				return r3sponse.error(f"Failed to add key [{private_key}] to the ssh agent #3.")"""
 
 		# without pass.
 		else:
-			output = utils.__execute__(command=["ssh-add", path], shell=False, timeout=timeout)
+			output = utils.__execute__(command=["ssh-add", private_key], shell=False, timeout=timeout)
 
 			# check success.
 			if "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
 				return r3sponse.error("Failed to communicate with the ssh-agent.")
 			elif "Identity added:" in output: 
-				return r3sponse.success(f"Successfully added key [{path}] to the ssh agent.")
+				return r3sponse.success(f"Successfully added key [{private_key}] to the ssh agent.")
 			else: 
-				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
+				return r3sponse.error(f"Failed to add key [{private_key}] to the ssh agent, error: {output}")
 
 		#
 	def delete(self):
@@ -323,12 +334,12 @@ response = agent.delete()
 
 # add a key to the agent.
 response = agent.add(
-	path="/path/to/mykey/private_key", 
+	private_key="/path/to/mykey/private_key", 
 	passphrase="TestPass!",)
 
 # add a smart cards key to the agent.
 response = agent.add(
-	path=smartcard.path, 
+	private_key=smartcard.path, 
 	smartcard=True,
 	pin=123456,)
 
