@@ -359,7 +359,7 @@ class Aliases(object):
 
 		# info.
 		json_config, config = {}, ""
-		if NETWORK_INFO["public_ip"] == public_ip:
+		if NETWORK_INFO["public_ip"] == public_ip and netw0rk.network.ping(private_ip, timeout=0.5).up == True:
 			ip = private_ip
 			port = private_port
 		else:
@@ -524,10 +524,10 @@ class Aliases(object):
 							if "is not added" not in response["error"]: return response
 							elif "is not added" in response["error"]:
 								if checked["smartcard"]:
-									response = agent.add(path=checked["private_key"], smartcard=True, pin=passphrase)
+									response = agent.add(private_key=checked["private_key"], smartcard=True, pin=passphrase)
 									if not response["success"]: return response
 								else:
-									response = agent.add(path=checked["private_key"], passphrase=passphrase)
+									response = agent.add(private_key=checked["private_key"], passphrase=passphrase)
 									if not response["success"]: return response
 						if new_passphrase:
 							# check encryption activated.
