@@ -6,12 +6,7 @@ ALIAS = "ssht00ls"
 
 # updates.
 import os, sys
-try: import cl1
-except ImportError: 
-	if os.path.exists("/usr/bin/pip3"): os.system(f"/usr/bin/pip3 install cl1 --user {syst3m.defaults.vars.user}")
-	else: os.system(f"pip3 install cl1")
-	import cl1
-if cl1.arguments_present(["--update"]):
+if "--update" in sys.argv:
 	os.system(f"curl -s https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ")
 	sys.exit(0)
 
@@ -30,7 +25,7 @@ try:
 except ImportError as e:
 	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('syst3m.defaults.vars.user')}")
+		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.pip --user {os.environ.get('syst3m.defaults.vars.user')}")
 	else:
 		os.system(f"pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.pip")
 
