@@ -135,7 +135,7 @@ class Keys(object):
 		elif not Files.exists(directory): 
 			os.mkdir(directory)
 			Files.chmod(path=directory, permission=700, sudo=True)
-			Files.chown(path=directory, owner=os.environ.get("syst3m.defaults.vars.user"), group=None, sudo=True)
+			Files.chown(path=directory, owner=syst3m.defaults.vars.user, group=None, sudo=True)
 
 		# options.
 		private_key = f'{directory}/private_key'
@@ -153,12 +153,12 @@ class Keys(object):
 
 		# permissions.
 		Files.chmod(path=private_key, permission=600, sudo=True)
-		Files.chown(path=private_key, owner=os.environ.get("syst3m.defaults.vars.user"), group=None, sudo=True)
+		Files.chown(path=private_key, owner=syst3m.defaults.vars.user, group=None, sudo=True)
 		os.system(f"mv '{private_key}.pub' '{public_key}'")
 		if not Files.exists(public_key): 
 			return r3sponse.error(f"Failed to move private key [{private_key}].")
 		Files.chmod(path=public_key, permission=640, sudo=True)
-		Files.chown(path=public_key, owner=os.environ.get("syst3m.defaults.vars.user"), group=None, sudo=True)
+		Files.chown(path=public_key, owner=syst3m.defaults.vars.user, group=None, sudo=True)
 
 		# response.
 		return r3sponse.success(f"Successfully generated key [{directory}].")
