@@ -35,7 +35,7 @@ class SmartCards(object):
 			self.original_path = f"{SOURCE_PATH}/lib/opensc/macos/opensc-pkcs11.so"
 			self.path = "/usr/local/lib/opensc-pkcs11_NOTALINK.so"
 			if not Files.exists(self.original_path):
-				raise syst3m.defaults.vars.osError("opensc package is not installed, run: [$ brew install yubico-piv-tool opensc].")
+				raise OSError("opensc package is not installed, run: [$ brew install yubico-piv-tool opensc].")
 
 	def scan(self, silent=False):
 
