@@ -84,7 +84,7 @@ class SSHD(object):
 		configuration += '\nMaxAuthTries 3'
 		configuration += '\nMaxSessions 10'
 		configuration += "\nMaxStartups 999"
-		configuration += '\nLogLevel VERBsyst3m.defaults.vars.osE'
+		configuration += '\nLogLevel VERBOSE'
 		configuration += f'\nPort {port}'
 		configuration += '\nProtocol 2'
 
@@ -186,7 +186,7 @@ class SSHD(object):
 		configuration += '\n    PasswordAuthentication no'
 		configuration += '\n    PermitEmptyPasswords no'
 		configuration += '\n    PubkeyAuthentication no'
-		configuration += f'\n    ForceCommand .ssh/utils/log.py "You are not authorized to access user [$syst3m.defaults.vars.user] over ssh."'
+		configuration += f'\n    ForceCommand .ssh/utils/log.py "You are not authorized to access user [$USER] over ssh."'
 		configuration += "\n"
 
 		# save sshd.
