@@ -190,7 +190,7 @@ class SSync(object):
 				passphrase = response.decrypted.decode()
 				
 				# tests.
-				response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
+				response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 				if not response["success"]: return response
 				response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 				if not response["success"]: return response
@@ -225,7 +225,7 @@ class SSync(object):
 			syst3m.utils.__execute_script__(f"""
 				
 				#!/bin/bash
-				# Set Icon to a File / Folder on macsyst3m.defaults.vars.os
+				# Set Icon to a File / Folder on macOS
 
 				icon="{icon}"
 				dest="{path}"
@@ -318,7 +318,7 @@ class SSync(object):
 				passphrase = response.decrypted.decode()
 				response = aliases.check(alias)
 				if not response["success"]: return response
-				response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
+				response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 				if not response["success"]: return response
 				if self.specific: self.activated = True
 		return self.utils.pull(
@@ -396,7 +396,7 @@ class SSync(object):
 				passphrase = response.decrypted.decode()
 				response = aliases.check(alias)
 				if not response["success"]: return response
-				response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
+				response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 				if not response["success"]: return response
 				if self.specific: self.activated = True
 		return self.utils.push(
