@@ -309,7 +309,7 @@ class Daemon(syst3m.objects.Thread):
 			try:
 				clean_index[subpath] = index[path]
 			except KeyError:
-				return r3sponse.error(f"Should not happen(#278363). (subpath: {subpath}), (path: {path}), (index: {json.dumps(index,indent=4)}), (remote index: {json.dumps(remote_index,indent=4)}).")
+				return r3sponse.error(f"Should not happen(#278363). (subpath: {subpath}), (path: {path}), (index: {index}), (remote index: {remote_index}).")
 		for path, mtime in remote_index.items():
 			subpath = self.subpath(path)
 			if subpath not in all_paths: 
@@ -318,7 +318,7 @@ class Daemon(syst3m.objects.Thread):
 			try:
 				remote_clean_index[subpath] = remote_index[path]
 			except KeyError:
-				return r3sponse.error(f"Should not happen(#739639). (subpath: {subpath}), (path: {path}), (index: {json.dumps(index,indent=4)}), (remote index: {json.dumps(remote_index,indent=4)}).")
+				return r3sponse.error(f"Should not happen(#739639). (subpath: {subpath}), (path: {path}), (index: {index}), (remote index: {remote_index}).")
 
 		# mismatches.
 		synchronized, mismatches = self.mismatches(clean_index, remote_clean_index, all_paths)
@@ -370,7 +370,7 @@ class Daemon(syst3m.objects.Thread):
 					"remote_mtime":rmtime,
 				}
 		synchronized = len(mismatches) == 0
-		if self.log_level >= 3: print(f'synchronized: {synchronized} clean_index: {json.dumps(clean_index,indent=4)}, remote_clean_index: {json.dumps(remote_clean_index,indent=4)} mismatches: {json.dumps(mismatches, indent=4)}.')
+		if self.log_level >= 3: print(f'synchronized: {synchronized} clean_index: {clean_index}, remote_clean_index: {remote_clean_index} mismatches: {mismatches}.')
 		return synchronized, mismatches
 		"""
 		mismatches, likeys, rikeys = {}, list(index.keys()), list(remote_index.keys())
@@ -398,7 +398,7 @@ class Daemon(syst3m.objects.Thread):
 						"local_mtime":lmtime,
 						"remote_mtime":rmtime,
 					}
-		return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {json.dumps(mismatches, indent=4)}].")
+		return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {mismatches}].")
 		"""
 	def process_mismatches(self, clean_index, remote_clean_index, mismatches):
 
@@ -425,7 +425,7 @@ class Daemon(syst3m.objects.Thread):
 			# should not happen.
 			if rmtime == None and lmtime == None: 
 				self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-				return r3sponse.error(f"No remote & local modification time present. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+				return r3sponse.error(f"No remote & local modification time present. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# one missing.
 			elif rmtime == None or lmtime == None:
@@ -459,7 +459,7 @@ class Daemon(syst3m.objects.Thread):
 				# should not happen.
 				else:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error(f"Should not happen (#3243443). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+					return r3sponse.error(f"Should not happen (#3243443). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# both present.
 			elif rmtime != None and lmtime != None:
@@ -479,12 +479,12 @@ class Daemon(syst3m.objects.Thread):
 				# should not happen.
 				else:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error(f"Unable to compare rmtime: {rmtime} & lmtime: {lmtime}. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+					return r3sponse.error(f"Unable to compare rmtime: {rmtime} & lmtime: {lmtime}. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# exceptions.
 			else:
 				self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-				return r3sponse.error(f"Should not happen (#407294). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+				return r3sponse.error(f"Should not happen (#407294). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# do not remove this exception.
 			# it is required for safe edits, to make sure a dir never gets synced unless it is created / removed.
@@ -496,7 +496,7 @@ class Daemon(syst3m.objects.Thread):
 				# add to updates.
 				if local_to_remote and remote_to_local:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error(f"Can not synchronize both remote to local & local to remote (rmtime: {rmtime}) (lmtime: {lmtime}), (last_rmtime: {last_rmtime}) (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+					return r3sponse.error(f"Can not synchronize both remote to local & local to remote (rmtime: {rmtime}) (lmtime: {lmtime}), (last_rmtime: {last_rmtime}) (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 				if "delete" in options: 
 					if self.log_level >= 1: 
 						if local_to_remote:
@@ -653,7 +653,7 @@ class Daemon(syst3m.objects.Thread):
 			if self.log_level > 0:
 				print(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 			if self.log_level >= 3:
-				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {json.dumps(response.index, indent=4)}, remote index: {json.dumps(response.remote_index, indent=4)}.")
+				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {response.index}, remote index: {response.remote_index}.")
 			else:
 				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 		"""
@@ -665,7 +665,7 @@ class Daemon(syst3m.objects.Thread):
 			if self.log_level >= 1:
 				print(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 			if self.log_level >= 3:
-				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {json.dumps(response.index, indent=4)}, remote index: {json.dumps(response.remote_index, indent=4)}.")
+				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {response.index}, remote index: {response.remote_index}.")
 			else:
 				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 		updates,deletions = response.unpack(["updates", "deletions"])
@@ -711,7 +711,7 @@ class Daemon(syst3m.objects.Thread):
 						inside_batch_size += 1
 					del depths[str(depth)]
 			if depths != {}:
-				return r3sponse.error(f"Should not happen(#234938). (depths: {depths}), (updates: {json.dumps(updates,indent=4)}).")
+				return r3sponse.error(f"Should not happen(#234938). (depths: {depths}), (updates: {updates}).")
 
 			# add directories.
 			for path, info in dir_updates.items():
@@ -724,7 +724,7 @@ class Daemon(syst3m.objects.Thread):
 				inside_batch_size += 1
 
 			# sum together as one command
-			#print("UPDAT BACTHES:",json.dumps(update_batches, indent=4))
+			#print("UPDAT BACTHES:",update_batches)
 			sum = True
 
 			# iterate updates.
@@ -749,7 +749,6 @@ class Daemon(syst3m.objects.Thread):
 							commands[batch_size] += [self.remote_to_local(path, info, command=sum)]
 
 			# execute commands.
-			#print("COMMANDS:",json.dumps(commands, indent=4))
 			if sum:
 				for batch_size, batch in commands.items():
 					loader, c = None, len(batch)
@@ -847,7 +846,7 @@ class Daemon(syst3m.objects.Thread):
 		response = self.index(short=True)
 		if not response["success"]: return response
 		elif not response.synchronized:
-			return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {json.dumps(response.mismatches, indent=4)}].")
+			return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {response.mismatches}].")
 
 		# handler.
 		return r3sponse.success(f"Successfully synchronized [{self.alias}:{self.path}] & [{self.path}].")
