@@ -1,7 +1,8 @@
 import os, sys
+from fil3s import *
 status = None
 path = sys.argv[1]
-if not os.path.exists(path):
+if not Files.exists(path):
 	status = "does-not-exist"
 elif os.path.isdir(path):
 	status = "directory"
